aboutsummaryrefslogtreecommitdiff
path: root/test/functional/rpc_bind.py
diff options
context:
space:
mode:
authorCarl Dong <accounts@carldong.me>2018-12-03 09:15:07 -0800
committerCarl Dong <accounts@carldong.me>2018-12-03 10:30:50 -0800
commitf3cf95ffdfda935f28260eb34bf20c1449a200c5 (patch)
tree847ba27d7cbe62317e85b13cdab719ccfa9e2d72 /test/functional/rpc_bind.py
parentc62b15118997030b007f04618cbca02d7abb1332 (diff)
downloadbitcoin-f3cf95ffdfda935f28260eb34bf20c1449a200c5.tar.xz
tests: Modify rpc_bind to conform to #14532 behaviour.
- Even when rpcallowip is specified, only bind localhost - Explicitly bind in run_allowip_test
Diffstat (limited to 'test/functional/rpc_bind.py')
-rwxr-xr-xtest/functional/rpc_bind.py11
1 files changed, 7 insertions, 4 deletions
diff --git a/test/functional/rpc_bind.py b/test/functional/rpc_bind.py
index 53916d5290..c23aa13685 100755
--- a/test/functional/rpc_bind.py
+++ b/test/functional/rpc_bind.py
@@ -48,9 +48,12 @@ class RPCBindTest(BitcoinTestFramework):
at a non-localhost IP.
'''
self.log.info("Allow IP test for %s:%d" % (rpchost, rpcport))
- base_args = ['-disablewallet', '-nolisten'] + ['-rpcallowip='+x for x in allow_ips]
+ node_args = \
+ ['-disablewallet', '-nolisten'] + \
+ ['-rpcallowip='+x for x in allow_ips] + \
+ ['-rpcbind='+addr for addr in ['127.0.0.1', "%s:%d" % (rpchost, rpcport)]] # Bind to localhost as well so start_nodes doesn't hang
self.nodes[0].rpchost = None
- self.start_nodes([base_args])
+ self.start_nodes([node_args])
# connect to node through non-loopback interface
node = get_rpc_proxy(rpc_url(self.nodes[0].datadir, 0, "%s:%d" % (rpchost, rpcport)), 0, coveragedir=self.options.coveragedir)
node.getnetworkinfo()
@@ -101,9 +104,9 @@ class RPCBindTest(BitcoinTestFramework):
# check default without rpcallowip (IPv4 and IPv6 localhost)
self.run_bind_test(None, '127.0.0.1', [],
[('127.0.0.1', self.defaultport), ('::1', self.defaultport)])
# check default with rpcallowip (IPv6 any)
self.run_bind_test(['127.0.0.1'], '127.0.0.1', [],
- [('::0', self.defaultport)])
+ [('127.0.0.1', self.defaultport), ('::1', self.defaultport)])
# check only IPv6 localhost (explicit)
self.run_bind_test(['[::1]'], '[::1]', ['[::1]'],
[('::1', self.defaultport)])
@@ -101,9 +104,9 @@ class RPCBindTest(BitcoinTestFramework):
self.run_bind_test(None, '127.0.0.1', [],
[('127.0.0.1', self.defaultport), ('::1', self.defaultport)])
- # check default with rpcallowip (IPv6 any)
+ # check default with rpcallowip (IPv4 and IPv6 localhost)
self.run_bind_test(['127.0.0.1'], '127.0.0.1', [],